pub struct BevyYarnProgram {
pub program: Program,
pub string_table: Handle<BevyYarnStringTable>,
pub metadata_table: Handle<BevyYarnMetadataTable>,
}Expand description
A newtype wrapping a yarn spinner program that can be loaded into the bevy engine.
Fields
program: ProgramThe program loaded from the yarnc file
string_table: Handle<BevyYarnStringTable>A handle for the string table for this yarnc file
metadata_table: Handle<BevyYarnMetadataTable>A handle for the metadata table for this yarnc file